@@ -9,40 +9,27 @@ par(mar=c(4.1, 4.1, 2.6, 1.6), cex=0.7, cex.main=1)))
 
 
 ###################################################
-### code chunk number 2: bivariate.Rnw:91-94
+### code chunk number 2: bivariate.Rnw:85-87
 ###################################################
-library (intoo)
 library (bivariate)
 library (moments)
 
 
 ###################################################
-### code chunk number 3: bivariate.Rnw:103-104
+### code chunk number 3: bivariate.Rnw:96-97
 ###################################################
 f = dubvpmf (1, 10, 1, 10)
 
 
 ###################################################
-### code chunk number 4: bivariate.Rnw:108-109
-###################################################
-object.info (f)
-
-
-###################################################
-### code chunk number 5: bivariate.Rnw:113-114
-###################################################
-f %$% n
-
-
-###################################################
-### code chunk number 6: bivariate.Rnw:120-121
+### code chunk number 4: bivariate.Rnw:103-104
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f)
 
 
 ###################################################
-### code chunk number 7: bivariate.Rnw:128-130
+### code chunk number 5: bivariate.Rnw:111-113
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 F = dubvcdf (1, 10, 1, 10)
@@ -50,13 +37,13 @@ plot (F)
 
 
 ###################################################
-### code chunk number 8: bivariate.Rnw:136-137
+### code chunk number 6: bivariate.Rnw:119-120
 ###################################################
 f (1, 1)
 
 
 ###################################################
-### code chunk number 9: bivariate.Rnw:158-160
+### code chunk number 7: bivariate.Rnw:141-143
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f = bnbvpmf (20, 0.5, 0.5)
@@ -64,7 +51,7 @@ plot (f)
 
 
 ###################################################
-### code chunk number 10: bivariate.Rnw:167-169
+### code chunk number 8: bivariate.Rnw:150-152
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 F = bnbvcdf (20, 0.5, 0.5)
@@ -72,7 +59,7 @@ plot (F)
 
 
 ###################################################
-### code chunk number 11: bivariate.Rnw:191-193
+### code chunk number 9: bivariate.Rnw:174-176
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f = pbvpmf (8, 8, 2)
@@ -80,7 +67,7 @@ plot (f)
 
 
 ###################################################
-### code chunk number 12: bivariate.Rnw:202-204
+### code chunk number 10: bivariate.Rnw:185-187
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 F = pbvcdf (8, 8, 2)
@@ -88,7 +75,7 @@ plot (F)
 
 
 ###################################################
-### code chunk number 13: bivariate.Rnw:216-218
+### code chunk number 11: bivariate.Rnw:199-201
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f = cubvpdf (0, 1, 0, 1)
@@ -96,14 +83,14 @@ plot (f)
 
 
 ###################################################
-### code chunk number 14: bivariate.Rnw:221-222
+### code chunk number 12: bivariate.Rnw:204-205
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, TRUE)
 
 
 ###################################################
-### code chunk number 15: bivariate.Rnw:229-231
+### code chunk number 13: bivariate.Rnw:212-214
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 F = cubvcdf (0, 1, 0, 1)
@@ -111,79 +98,73 @@ plot (F)
 
 
 ###################################################
-### code chunk number 16: bivariate.Rnw:234-235
+### code chunk number 14: bivariate.Rnw:217-218
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F, TRUE)
 
 
 ###################################################
-### code chunk number 17: bivariate.Rnw:246-247
+### code chunk number 15: bivariate.Rnw:229-230
 ###################################################
 f = nbvpdf (0, 0, 1, 1, 0)
 
 
 ###################################################
-### code chunk number 18: bivariate.Rnw:252-253
+### code chunk number 16: bivariate.Rnw:235-236
 ###################################################
 #f = nbvpdf (mean.x, mean,y, sd.x ^ 2, sd.y ^ 2, sd.x * sd.y * cor.xy)
 
 
 ###################################################
-### code chunk number 19: bivariate.Rnw:257-258
-###################################################
-object.info (f)
-
-
-###################################################
-### code chunk number 20: bivariate.Rnw:264-265
+### code chunk number 17: bivariate.Rnw:242-243
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f)
 
 
 ###################################################
-### code chunk number 21: bivariate.Rnw:268-269
+### code chunk number 18: bivariate.Rnw:246-247
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, TRUE)
 
 
 ###################################################
-### code chunk number 22: bivariate.Rnw:275-276
+### code chunk number 19: bivariate.Rnw:253-254
 ###################################################
 F = nbvcdf (0, 0, 1, 1, 0)
 
 
 ###################################################
-### code chunk number 23: bivariate.Rnw:280-281
+### code chunk number 20: bivariate.Rnw:258-259
 ###################################################
 #F = nbvcdf (mean.x, mean,y, sd.x ^ 2, sd.y ^ 2, sd.x * sd.y * cor.xy)
 
 
 ###################################################
-### code chunk number 24: bivariate.Rnw:287-288
+### code chunk number 21: bivariate.Rnw:265-266
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F)
 
 
 ###################################################
-### code chunk number 25: bivariate.Rnw:291-292
+### code chunk number 22: bivariate.Rnw:269-270
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F, TRUE)
 
 
 ###################################################
-### code chunk number 26: bivariate.Rnw:304-305
+### code chunk number 23: bivariate.Rnw:282-283
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, all=TRUE)
 
 
 ###################################################
-### code chunk number 27: bivariate.Rnw:314-316
+### code chunk number 24: bivariate.Rnw:292-294
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f2 = nbvpdf (0, 0, 1, 1, 0.75)
@@ -191,7 +172,7 @@ plot (f2, all=TRUE)
 
 
 ###################################################
-### code chunk number 28: bivariate.Rnw:323-325
+### code chunk number 25: bivariate.Rnw:301-303
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f3 = nbvpdf (0, 0, 1, 1, -0.75)
@@ -199,7 +180,7 @@ plot (f3, all=TRUE)
 
 
 ###################################################
-### code chunk number 29: bivariate.Rnw:337-339
+### code chunk number 26: bivariate.Rnw:315-317
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f = bmbvpdf (3.5, 0, 1, 1, 6.5, 0, 1, 1)
@@ -207,14 +188,14 @@ plot (f)
 
 
 ###################################################
-### code chunk number 30: bivariate.Rnw:342-343
+### code chunk number 27: bivariate.Rnw:320-321
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, TRUE, npoints=40)
 
 
 ###################################################
-### code chunk number 31: bivariate.Rnw:350-352
+### code chunk number 28: bivariate.Rnw:328-330
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 F = bmbvcdf (3.5, 0, 1, 1, 6.5, 0, 1, 1)
@@ -222,21 +203,21 @@ plot (F)
 
 
 ###################################################
-### code chunk number 32: bivariate.Rnw:355-356
+### code chunk number 29: bivariate.Rnw:333-334
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F, TRUE, npoints=40)
 
 
 ###################################################
-### code chunk number 33: bivariate.Rnw:368-369
+### code chunk number 30: bivariate.Rnw:346-347
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, npoints=20, all=TRUE)
 
 
 ###################################################
-### code chunk number 34: bivariate.Rnw:377-379
+### code chunk number 31: bivariate.Rnw:355-357
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f2 = bmbvpdf (3.5, 3.5, 1, 1, 6.5, 6.5, 1, 1)
@@ -244,7 +225,7 @@ plot (f2, npoints=20, all=TRUE)
 
 
 ###################################################
-### code chunk number 35: bivariate.Rnw:385-387
+### code chunk number 32: bivariate.Rnw:363-365
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 f3 = bmbvpdf (3.5, -3.5, 1, 1, 6.5, -6.5, 1, 1)
@@ -252,26 +233,20 @@ plot (f3, npoints=20, all=TRUE)
 
 
 ###################################################
-### code chunk number 36: bivariate.Rnw:400-402
+### code chunk number 33: bivariate.Rnw:378-380
 ###################################################
 data ("geyser", package="MASS")
 attach (geyser)
 
 
 ###################################################
-### code chunk number 37: bivariate.Rnw:405-406
+### code chunk number 34: bivariate.Rnw:383-384
 ###################################################
 f = kbvpdf (duration, waiting, 0.7, 7)
 
 
 ###################################################
-### code chunk number 38: bivariate.Rnw:410-411
-###################################################
-object.info (f)
-
-
-###################################################
-### code chunk number 39: bivariate.Rnw:417-419
+### code chunk number 35: bivariate.Rnw:389-391
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 
@@ -279,14 +254,14 @@ plot (f, xlab="duration", ylab="waiting")
 
 
 ###################################################
-### code chunk number 40: bivariate.Rnw:422-423
+### code chunk number 36: bivariate.Rnw:394-395
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, TRUE, xlab="duration", ylab="waiting")
 
 
 ###################################################
-### code chunk number 41: bivariate.Rnw:430-432
+### code chunk number 37: bivariate.Rnw:402-404
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 F = kbvcdf (duration, waiting, 0.7, 7)
@@ -294,20 +269,21 @@ plot (F, xlab="duration", ylab="waiting")
 
 
 ###################################################
-### code chunk number 42: bivariate.Rnw:435-436
+### code chunk number 38: bivariate.Rnw:407-408
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F, TRUE, xlab="duration", ylab="waiting")
 
 
 ###################################################
-### code chunk number 43: bivariate.Rnw:484-489
+### code chunk number 39: bivariate.Rnw:452-458
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-str (geyser)
+head (geyser, 3)
+tail (geyser, 3)
 summary (geyser)
-cov (geyser)
 skewness (geyser)
+cov (geyser)
 plot (duration, waiting)
 
 
